@@ -1,5 +1,4 @@
 #!/usr/bin/env python
 
-__version__ = '0.0.1'
-
 from .channels import Channels
+channels = Channels()
